"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import typing

import google.protobuf.descriptor
import google.protobuf.message
import tensorflow.core.framework.tensor_description_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MemoryLogStep(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEP_ID_FIELD_NUMBER: builtins.int
    HANDLE_FIELD_NUMBER: builtins.int
    step_id: builtins.int
    """Process-unique step id."""
    handle: builtins.str
    """Handle describing the feeds and fetches of the step."""
    def __init__(self, *, step_id: builtins.int | None = ..., handle: builtins.str | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["handle", b"handle", "step_id", b"step_id"]) -> None: ...

global___MemoryLogStep = MemoryLogStep

@typing.final
class MemoryLogTensorAllocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEP_ID_FIELD_NUMBER: builtins.int
    KERNEL_NAME_FIELD_NUMBER: builtins.int
    TENSOR_FIELD_NUMBER: builtins.int
    step_id: builtins.int
    """Process-unique step id."""
    kernel_name: builtins.str
    """Name of the kernel making the allocation as set in GraphDef,
    e.g., "affine2/weights/Assign".
    """
    @property
    def tensor(self) -> tensorflow.core.framework.tensor_description_pb2.TensorDescription:
        """Allocated tensor details."""

    def __init__(
        self,
        *,
        step_id: builtins.int | None = ...,
        kernel_name: builtins.str | None = ...,
        tensor: tensorflow.core.framework.tensor_description_pb2.TensorDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tensor", b"tensor"]) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["kernel_name", b"kernel_name", "step_id", b"step_id", "tensor", b"tensor"]
    ) -> None: ...

global___MemoryLogTensorAllocation = MemoryLogTensorAllocation

@typing.final
class MemoryLogTensorDeallocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOCATION_ID_FIELD_NUMBER: builtins.int
    ALLOCATOR_NAME_FIELD_NUMBER: builtins.int
    allocation_id: builtins.int
    """Id of the tensor buffer being deallocated, used to match to a
    corresponding allocation.
    """
    allocator_name: builtins.str
    """Name of the allocator used."""
    def __init__(self, *, allocation_id: builtins.int | None = ..., allocator_name: builtins.str | None = ...) -> None: ...
    def ClearField(
        self, field_name: typing.Literal["allocation_id", b"allocation_id", "allocator_name", b"allocator_name"]
    ) -> None: ...

global___MemoryLogTensorDeallocation = MemoryLogTensorDeallocation

@typing.final
class MemoryLogTensorOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEP_ID_FIELD_NUMBER: builtins.int
    KERNEL_NAME_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TENSOR_FIELD_NUMBER: builtins.int
    step_id: builtins.int
    """Process-unique step id."""
    kernel_name: builtins.str
    """Name of the kernel producing an output as set in GraphDef, e.g.,
    "affine2/weights/Assign".
    """
    index: builtins.int
    """Index of the output being set."""
    @property
    def tensor(self) -> tensorflow.core.framework.tensor_description_pb2.TensorDescription:
        """Output tensor details."""

    def __init__(
        self,
        *,
        step_id: builtins.int | None = ...,
        kernel_name: builtins.str | None = ...,
        index: builtins.int | None = ...,
        tensor: tensorflow.core.framework.tensor_description_pb2.TensorDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tensor", b"tensor"]) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["index", b"index", "kernel_name", b"kernel_name", "step_id", b"step_id", "tensor", b"tensor"],
    ) -> None: ...

global___MemoryLogTensorOutput = MemoryLogTensorOutput

@typing.final
class MemoryLogRawAllocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEP_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    NUM_BYTES_FIELD_NUMBER: builtins.int
    PTR_FIELD_NUMBER: builtins.int
    ALLOCATION_ID_FIELD_NUMBER: builtins.int
    ALLOCATOR_NAME_FIELD_NUMBER: builtins.int
    step_id: builtins.int
    """Process-unique step id."""
    operation: builtins.str
    """Name of the operation making the allocation."""
    num_bytes: builtins.int
    """Number of bytes in the allocation."""
    ptr: builtins.int
    """Address of the allocation."""
    allocation_id: builtins.int
    """Id of the tensor buffer being allocated, used to match to a
    corresponding deallocation.
    """
    allocator_name: builtins.str
    """Name of the allocator used."""
    def __init__(
        self,
        *,
        step_id: builtins.int | None = ...,
        operation: builtins.str | None = ...,
        num_bytes: builtins.int | None = ...,
        ptr: builtins.int | None = ...,
        allocation_id: builtins.int | None = ...,
        allocator_name: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "allocation_id",
            b"allocation_id",
            "allocator_name",
            b"allocator_name",
            "num_bytes",
            b"num_bytes",
            "operation",
            b"operation",
            "ptr",
            b"ptr",
            "step_id",
            b"step_id",
        ],
    ) -> None: ...

global___MemoryLogRawAllocation = MemoryLogRawAllocation

@typing.final
class MemoryLogRawDeallocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEP_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    ALLOCATION_ID_FIELD_NUMBER: builtins.int
    ALLOCATOR_NAME_FIELD_NUMBER: builtins.int
    DEFERRED_FIELD_NUMBER: builtins.int
    step_id: builtins.int
    """Process-unique step id."""
    operation: builtins.str
    """Name of the operation making the deallocation."""
    allocation_id: builtins.int
    """Id of the tensor buffer being deallocated, used to match to a
    corresponding allocation.
    """
    allocator_name: builtins.str
    """Name of the allocator used."""
    deferred: builtins.bool
    """True if the deallocation is queued and will be performed later,
    e.g. for GPU lazy freeing of buffers.
    """
    def __init__(
        self,
        *,
        step_id: builtins.int | None = ...,
        operation: builtins.str | None = ...,
        allocation_id: builtins.int | None = ...,
        allocator_name: builtins.str | None = ...,
        deferred: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "allocation_id",
            b"allocation_id",
            "allocator_name",
            b"allocator_name",
            "deferred",
            b"deferred",
            "operation",
            b"operation",
            "step_id",
            b"step_id",
        ],
    ) -> None: ...

global___MemoryLogRawDeallocation = MemoryLogRawDeallocation



from collections.abc import Iterable
from typing import ClassVar

from .core import Calendar

class IsoRegistry:
    STANDARD_MODULES: ClassVar[tuple[str, ...]]
    region_registry: dict[str, type[Calendar]]
    def __init__(self, load_standard_modules: bool | None = True) -> None: ...
    def register(self, iso_code: str, cls: type[Calendar]) -> None: ...
    def load_module_from_items(self, module_name: str, items: Iterable[str]) -> None: ...
    def get(self, iso_code: str) -> type[Calendar]: ...
    def get_subregions(self, iso_code: str) -> dict[str, type[Calendar]]: ...
    def get_calendars(
        self, region_codes: Iterable[str] | None = None, include_subregions: bool | None = False
    ) -> dict[str, type[Calendar]]: ...

registry: IsoRegistry



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import typing

import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InterconnectLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STRENGTH_FIELD_NUMBER: builtins.int
    device_id: builtins.int
    type: builtins.str
    strength: builtins.int
    def __init__(
        self, *, device_id: builtins.int | None = ..., type: builtins.str | None = ..., strength: builtins.int | None = ...
    ) -> None: ...
    def ClearField(
        self, field_name: typing.Literal["device_id", b"device_id", "strength", b"strength", "type", b"type"]
    ) -> None: ...

global___InterconnectLink = InterconnectLink

@typing.final
class LocalLinks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINK_FIELD_NUMBER: builtins.int
    @property
    def link(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InterconnectLink]: ...
    def __init__(self, *, link: collections.abc.Iterable[global___InterconnectLink] | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["link", b"link"]) -> None: ...

global___LocalLinks = LocalLinks

@typing.final
class DeviceLocality(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    NUMA_NODE_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    bus_id: builtins.int
    """Optional bus locality of device.  Default value of 0 means
    no specific locality.  Specific localities are indexed from 1.
    """
    numa_node: builtins.int
    """Optional NUMA locality of device."""
    @property
    def links(self) -> global___LocalLinks:
        """Optional local interconnect links to other devices."""

    def __init__(
        self, *, bus_id: builtins.int | None = ..., numa_node: builtins.int | None = ..., links: global___LocalLinks | None = ...
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["links", b"links"]) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["bus_id", b"bus_id", "links", b"links", "numa_node", b"numa_node"]
    ) -> None: ...

global___DeviceLocality = DeviceLocality

@typing.final
class DeviceAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    LOCALITY_FIELD_NUMBER: builtins.int
    INCARNATION_FIELD_NUMBER: builtins.int
    PHYSICAL_DEVICE_DESC_FIELD_NUMBER: builtins.int
    XLA_GLOBAL_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Fully specified name of the device within a cluster."""
    device_type: builtins.str
    """String representation of device_type."""
    memory_limit: builtins.int
    """Memory capacity of device in bytes."""
    incarnation: builtins.int
    """A device is assigned a global unique number each time it is
    initialized. "incarnation" should never be 0.
    """
    physical_device_desc: builtins.str
    """String representation of the physical device that this device maps to."""
    xla_global_id: builtins.int
    """A physical device ID for use in XLA DeviceAssignments, unique across
    clients in a multi-client setup. Set to -1 if unavailable, non-negative
    otherwise.
    """
    @property
    def locality(self) -> global___DeviceLocality:
        """Platform-specific data about device that may be useful
        for supporting efficient data transfers.
        """

    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        device_type: builtins.str | None = ...,
        memory_limit: builtins.int | None = ...,
        locality: global___DeviceLocality | None = ...,
        incarnation: builtins.int | None = ...,
        physical_device_desc: builtins.str | None = ...,
        xla_global_id: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["locality", b"locality"]) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "device_type",
            b"device_type",
            "incarnation",
            b"incarnation",
            "locality",
            b"locality",
            "memory_limit",
            b"memory_limit",
            "name",
            b"name",
            "physical_device_desc",
            b"physical_device_desc",
            "xla_global_id",
            b"xla_global_id",
        ],
    ) -> None: ...

global___DeviceAttributes = DeviceAttributes



from types import ModuleType
from typing import ClassVar
from typing_extensions import deprecated

from docutils import nodes
from docutils.transforms import Transform

@deprecated("The `recommonmark` package is unmaintained and deprecated; will be removed in Docutils 1.0.")
class pending_xref(nodes.Inline, nodes.Element): ...

sphinx: ModuleType

@deprecated("The `recommonmark` package is unmaintained and deprecated; will be removed in Docutils 1.0.")
def is_literal(node: nodes.Node) -> bool: ...
@deprecated("The `recommonmark` package is unmaintained and deprecated; will be removed in Docutils 1.0.")
class _CommonMarkParser:
    default_config: ClassVar[dict[str, None]]
    def __init__(self) -> None: ...
    def convert_ast(self, ast): ...
    def default_visit(self, mdnode): ...
    def default_depart(self, mdnode): ...
    def visit_heading(self, mdnode): ...
    def depart_heading(self, _): ...
    def visit_text(self, mdnode): ...
    def visit_softbreak(self, _): ...
    def visit_linebreak(self, _): ...
    def visit_paragraph(self, mdnode): ...
    def visit_emph(self, _): ...
    def visit_strong(self, _): ...
    def visit_code(self, mdnode): ...
    def visit_link(self, mdnode): ...
    def depart_link(self, mdnode): ...
    def visit_image(self, mdnode): ...
    def visit_list(self, mdnode): ...
    def visit_item(self, mdnode): ...
    def visit_code_block(self, mdnode): ...
    def visit_block_quote(self, mdnode): ...
    def visit_html(self, mdnode): ...
    def visit_html_inline(self, mdnode): ...
    def visit_html_block(self, mdnode): ...
    def visit_thematic_break(self, _): ...
    def setup_sections(self): ...
    def add_section(self, section, level): ...
    def is_section_level(self, level, section): ...

@deprecated("The `recommonmark` package is unmaintained and deprecated; will be removed in Docutils 1.0.")
class Parser(_CommonMarkParser):
    supported: ClassVar[tuple[str, ...]]
    config_section: ClassVar[str]
    config_section_dependencies: ClassVar[tuple[str, ...]]
    def get_transforms(self) -> list[type[Transform]]: ...
    def parse(self, inputstring: str, document: nodes.document) -> None: ...
    def visit_document(self, node) -> None: ...
    def visit_text(self, mdnode) -> None: ...



from typing import Final

def lookup(code: str, _cache: dict[str, str] = {}) -> str: ...

CLASS_SUCCESSFUL_COMPLETION: Final[str]
CLASS_WARNING: Final[str]
CLASS_NO_DATA: Final[str]
CLASS_SQL_STATEMENT_NOT_YET_COMPLETE: Final[str]
CLASS_CONNECTION_EXCEPTION: Final[str]
CLASS_TRIGGERED_ACTION_EXCEPTION: Final[str]
CLASS_FEATURE_NOT_SUPPORTED: Final[str]
CLASS_INVALID_TRANSACTION_INITIATION: Final[str]
CLASS_LOCATOR_EXCEPTION: Final[str]
CLASS_INVALID_GRANTOR: Final[str]
CLASS_INVALID_ROLE_SPECIFICATION: Final[str]
CLASS_DIAGNOSTICS_EXCEPTION: Final[str]
CLASS_XQUERY_ERROR: Final[str]
CLASS_CASE_NOT_FOUND: Final[str]
CLASS_CARDINALITY_VIOLATION: Final[str]
CLASS_DATA_EXCEPTION: Final[str]
CLASS_INTEGRITY_CONSTRAINT_VIOLATION: Final[str]
CLASS_INVALID_CURSOR_STATE: Final[str]
CLASS_INVALID_TRANSACTION_STATE: Final[str]
CLASS_INVALID_SQL_STATEMENT_NAME: Final[str]
CLASS_TRIGGERED_DATA_CHANGE_VIOLATION: Final[str]
CLASS_INVALID_AUTHORIZATION_SPECIFICATION: Final[str]
CLASS_DEPENDENT_PRIVILEGE_DESCRIPTORS_STILL_EXIST: Final[str]
CLASS_INVALID_TRANSACTION_TERMINATION: Final[str]
CLASS_SQL_ROUTINE_EXCEPTION: Final[str]
CLASS_INVALID_CURSOR_NAME: Final[str]
CLASS_EXTERNAL_ROUTINE_EXCEPTION: Final[str]
CLASS_EXTERNAL_ROUTINE_INVOCATION_EXCEPTION: Final[str]
CLASS_SAVEPOINT_EXCEPTION: Final[str]
CLASS_INVALID_CATALOG_NAME: Final[str]
CLASS_INVALID_SCHEMA_NAME: Final[str]
CLASS_TRANSACTION_ROLLBACK: Final[str]
CLASS_SYNTAX_ERROR_OR_ACCESS_RULE_VIOLATION: Final[str]
CLASS_WITH_CHECK_OPTION_VIOLATION: Final[str]
CLASS_INSUFFICIENT_RESOURCES: Final[str]
CLASS_PROGRAM_LIMIT_EXCEEDED: Final[str]
CLASS_OBJECT_NOT_IN_PREREQUISITE_STATE: Final[str]
CLASS_OPERATOR_INTERVENTION: Final[str]
CLASS_SYSTEM_ERROR: Final[str]
CLASS_SNAPSHOT_FAILURE: Final[str]
CLASS_CONFIGURATION_FILE_ERROR: Final[str]
CLASS_FOREIGN_DATA_WRAPPER_ERROR: Final[str]
CLASS_PL_PGSQL_ERROR: Final[str]
CLASS_INTERNAL_ERROR: Final[str]
SUCCESSFUL_COMPLETION: Final[str]
WARNING: Final[str]
NULL_VALUE_ELIMINATED_IN_SET_FUNCTION: Final[str]
STRING_DATA_RIGHT_TRUNCATION_: Final[str]
PRIVILEGE_NOT_REVOKED: Final[str]
PRIVILEGE_NOT_GRANTED: Final[str]
IMPLICIT_ZERO_BIT_PADDING: Final[str]
DYNAMIC_RESULT_SETS_RETURNED: Final[str]
DEPRECATED_FEATURE: Final[str]
NO_DATA: Final[str]
NO_ADDITIONAL_DYNAMIC_RESULT_SETS_RETURNED: Final[str]
SQL_STATEMENT_NOT_YET_COMPLETE: Final[str]
CONNECTION_EXCEPTION: Final[str]
SQLCLIENT_UNABLE_TO_ESTABLISH_SQLCONNECTION: Final[str]
CONNECTION_DOES_NOT_EXIST: Final[str]
SQLSERVER_REJECTED_ESTABLISHMENT_OF_SQLCONNECTION: Final[str]
CONNECTION_FAILURE: Final[str]
TRANSACTION_RESOLUTION_UNKNOWN: Final[str]
PROTOCOL_VIOLATION: Final[str]
TRIGGERED_ACTION_EXCEPTION: Final[str]
FEATURE_NOT_SUPPORTED: Final[str]
INVALID_TRANSACTION_INITIATION: Final[str]
LOCATOR_EXCEPTION: Final[str]
INVALID_LOCATOR_SPECIFICATION: Final[str]
INVALID_GRANTOR: Final[str]
INVALID_GRANT_OPERATION: Final[str]
INVALID_ROLE_SPECIFICATION: Final[str]
DIAGNOSTICS_EXCEPTION: Final[str]
STACKED_DIAGNOSTICS_ACCESSED_WITHOUT_ACTIVE_HANDLER: Final[str]
INVALID_ARGUMENT_FOR_XQUERY: Final[str]
CASE_NOT_FOUND: Final[str]
CARDINALITY_VIOLATION: Final[str]
DATA_EXCEPTION: Final[str]
STRING_DATA_RIGHT_TRUNCATION: Final[str]
NULL_VALUE_NO_INDICATOR_PARAMETER: Final[str]
NUMERIC_VALUE_OUT_OF_RANGE: Final[str]
NULL_VALUE_NOT_ALLOWED_: Final[str]
ERROR_IN_ASSIGNMENT: Final[str]
INVALID_DATETIME_FORMAT: Final[str]
DATETIME_FIELD_OVERFLOW: Final[str]
INVALID_TIME_ZONE_DISPLACEMENT_VALUE: Final[str]
ESCAPE_CHARACTER_CONFLICT: Final[str]
INVALID_USE_OF_ESCAPE_CHARACTER: Final[str]
INVALID_ESCAPE_OCTET: Final[str]
ZERO_LENGTH_CHARACTER_STRING: Final[str]
MOST_SPECIFIC_TYPE_MISMATCH: Final[str]
SEQUENCE_GENERATOR_LIMIT_EXCEEDED: Final[str]
NOT_AN_XML_DOCUMENT: Final[str]
INVALID_XML_DOCUMENT: Final[str]
INVALID_XML_CONTENT: Final[str]
INVALID_XML_COMMENT: Final[str]
INVALID_XML_PROCESSING_INSTRUCTION: Final[str]
INVALID_INDICATOR_PARAMETER_VALUE: Final[str]
SUBSTRING_ERROR: Final[str]
DIVISION_BY_ZERO: Final[str]
INVALID_PRECEDING_OR_FOLLOWING_SIZE: Final[str]
INVALID_ARGUMENT_FOR_NTILE_FUNCTION: Final[str]
INTERVAL_FIELD_OVERFLOW: Final[str]
INVALID_ARGUMENT_FOR_NTH_VALUE_FUNCTION: Final[str]
INVALID_CHARACTER_VALUE_FOR_CAST: Final[str]
INVALID_ESCAPE_CHARACTER: Final[str]
INVALID_REGULAR_EXPRESSION: Final[str]
INVALID_ARGUMENT_FOR_LOGARITHM: Final[str]
INVALID_ARGUMENT_FOR_POWER_FUNCTION: Final[str]
INVALID_ARGUMENT_FOR_WIDTH_BUCKET_FUNCTION: Final[str]
INVALID_ROW_COUNT_IN_LIMIT_CLAUSE: Final[str]
INVALID_ROW_COUNT_IN_RESULT_OFFSET_CLAUSE: Final[str]
INVALID_LIMIT_VALUE: Final[str]
CHARACTER_NOT_IN_REPERTOIRE: Final[str]
INDICATOR_OVERFLOW: Final[str]
INVALID_PARAMETER_VALUE: Final[str]
UNTERMINATED_C_STRING: Final[str]
INVALID_ESCAPE_SEQUENCE: Final[str]
STRING_DATA_LENGTH_MISMATCH: Final[str]
TRIM_ERROR: Final[str]
ARRAY_SUBSCRIPT_ERROR: Final[str]
INVALID_TABLESAMPLE_REPEAT: Final[str]
INVALID_TABLESAMPLE_ARGUMENT: Final[str]
DUPLICATE_JSON_OBJECT_KEY_VALUE: Final[str]
INVALID_ARGUMENT_FOR_SQL_JSON_DATETIME_FUNCTION: Final[str]
INVALID_JSON_TEXT: Final[str]
INVALID_SQL_JSON_SUBSCRIPT: Final[str]
MORE_THAN_ONE_SQL_JSON_ITEM: Final[str]
NO_SQL_JSON_ITEM: Final[str]
NON_NUMERIC_SQL_JSON_ITEM: Final[str]
NON_UNIQUE_KEYS_IN_A_JSON_OBJECT: Final[str]
SINGLETON_SQL_JSON_ITEM_REQUIRED: Final[str]
SQL_JSON_ARRAY_NOT_FOUND: Final[str]
SQL_JSON_MEMBER_NOT_FOUND: Final[str]
SQL_JSON_NUMBER_NOT_FOUND: Final[str]
SQL_JSON_OBJECT_NOT_FOUND: Final[str]
TOO_MANY_JSON_ARRAY_ELEMENTS: Final[str]
TOO_MANY_JSON_OBJECT_MEMBERS: Final[str]
SQL_JSON_SCALAR_REQUIRED: Final[str]
FLOATING_POINT_EXCEPTION: Final[str]
INVALID_TEXT_REPRESENTATION: Final[str]
INVALID_BINARY_REPRESENTATION: Final[str]
BAD_COPY_FILE_FORMAT: Final[str]
UNTRANSLATABLE_CHARACTER: Final[str]
NONSTANDARD_USE_OF_ESCAPE_CHARACTER: Final[str]
INTEGRITY_CONSTRAINT_VIOLATION: Final[str]
RESTRICT_VIOLATION: Final[str]
NOT_NULL_VIOLATION: Final[str]
FOREIGN_KEY_VIOLATION: Final[str]
UNIQUE_VIOLATION: Final[str]
CHECK_VIOLATION: Final[str]
EXCLUSION_VIOLATION: Final[str]
INVALID_CURSOR_STATE: Final[str]
INVALID_TRANSACTION_STATE: Final[str]
ACTIVE_SQL_TRANSACTION: Final[str]
BRANCH_TRANSACTION_ALREADY_ACTIVE: Final[str]
INAPPROPRIATE_ACCESS_MODE_FOR_BRANCH_TRANSACTION: Final[str]
INAPPROPRIATE_ISOLATION_LEVEL_FOR_BRANCH_TRANSACTION: Final[str]
NO_ACTIVE_SQL_TRANSACTION_FOR_BRANCH_TRANSACTION: Final[str]
READ_ONLY_SQL_TRANSACTION: Final[str]
SCHEMA_AND_DATA_STATEMENT_MIXING_NOT_SUPPORTED: Final[str]
HELD_CURSOR_REQUIRES_SAME_ISOLATION_LEVEL: Final[str]
NO_ACTIVE_SQL_TRANSACTION: Final[str]
IN_FAILED_SQL_TRANSACTION: Final[str]
IDLE_IN_TRANSACTION_SESSION_TIMEOUT: Final[str]
INVALID_SQL_STATEMENT_NAME: Final[str]
TRIGGERED_DATA_CHANGE_VIOLATION: Final[str]
INVALID_AUTHORIZATION_SPECIFICATION: Final[str]
INVALID_PASSWORD: Final[str]
DEPENDENT_PRIVILEGE_DESCRIPTORS_STILL_EXIST: Final[str]
DEPENDENT_OBJECTS_STILL_EXIST: Final[str]
INVALID_TRANSACTION_TERMINATION: Final[str]
SQL_ROUTINE_EXCEPTION: Final[str]
MODIFYING_SQL_DATA_NOT_PERMITTED_: Final[str]
PROHIBITED_SQL_STATEMENT_ATTEMPTED_: Final[str]
READING_SQL_DATA_NOT_PERMITTED_: Final[str]
FUNCTION_EXECUTED_NO_RETURN_STATEMENT: Final[str]
INVALID_CURSOR_NAME: Final[str]
EXTERNAL_ROUTINE_EXCEPTION: Final[str]
CONTAINING_SQL_NOT_PERMITTED: Final[str]
MODIFYING_SQL_DATA_NOT_PERMITTED: Final[str]
PROHIBITED_SQL_STATEMENT_ATTEMPTED: Final[str]
READING_SQL_DATA_NOT_PERMITTED: Final[str]
EXTERNAL_ROUTINE_INVOCATION_EXCEPTION: Final[str]
INVALID_SQLSTATE_RETURNED: Final[str]
NULL_VALUE_NOT_ALLOWED: Final[str]
TRIGGER_PROTOCOL_VIOLATED: Final[str]
SRF_PROTOCOL_VIOLATED: Final[str]
EVENT_TRIGGER_PROTOCOL_VIOLATED: Final[str]
SAVEPOINT_EXCEPTION: Final[str]
INVALID_SAVEPOINT_SPECIFICATION: Final[str]
INVALID_CATALOG_NAME: Final[str]
INVALID_SCHEMA_NAME: Final[str]
TRANSACTION_ROLLBACK: Final[str]
SERIALIZATION_FAILURE: Final[str]
TRANSACTION_INTEGRITY_CONSTRAINT_VIOLATION: Final[str]
STATEMENT_COMPLETION_UNKNOWN: Final[str]
DEADLOCK_DETECTED: Final[str]
SYNTAX_ERROR_OR_ACCESS_RULE_VIOLATION: Final[str]
INSUFFICIENT_PRIVILEGE: Final[str]
SYNTAX_ERROR: Final[str]
INVALID_NAME: Final[str]
INVALID_COLUMN_DEFINITION: Final[str]
NAME_TOO_LONG: Final[str]
DUPLICATE_COLUMN: Final[str]
AMBIGUOUS_COLUMN: Final[str]
UNDEFINED_COLUMN: Final[str]
UNDEFINED_OBJECT: Final[str]
DUPLICATE_OBJECT: Final[str]
DUPLICATE_ALIAS: Final[str]
DUPLICATE_FUNCTION: Final[str]
AMBIGUOUS_FUNCTION: Final[str]
GROUPING_ERROR: Final[str]
DATATYPE_MISMATCH: Final[str]
WRONG_OBJECT_TYPE: Final[str]
INVALID_FOREIGN_KEY: Final[str]
CANNOT_COERCE: Final[str]
UNDEFINED_FUNCTION: Final[str]
GENERATED_ALWAYS: Final[str]
RESERVED_NAME: Final[str]
UNDEFINED_TABLE: Final[str]
UNDEFINED_PARAMETER: Final[str]
DUPLICATE_CURSOR: Final[str]
DUPLICATE_DATABASE: Final[str]
DUPLICATE_PREPARED_STATEMENT: Final[str]
DUPLICATE_SCHEMA: Final[str]
DUPLICATE_TABLE: Final[str]
AMBIGUOUS_PARAMETER: Final[str]
AMBIGUOUS_ALIAS: Final[str]
INVALID_COLUMN_REFERENCE: Final[str]
INVALID_CURSOR_DEFINITION: Final[str]
INVALID_DATABASE_DEFINITION: Final[str]
INVALID_FUNCTION_DEFINITION: Final[str]
INVALID_PREPARED_STATEMENT_DEFINITION: Final[str]
INVALID_SCHEMA_DEFINITION: Final[str]
INVALID_TABLE_DEFINITION: Final[str]
INVALID_OBJECT_DEFINITION: Final[str]
INDETERMINATE_DATATYPE: Final[str]
INVALID_RECURSION: Final[str]
WINDOWING_ERROR: Final[str]
COLLATION_MISMATCH: Final[str]
INDETERMINATE_COLLATION: Final[str]
WITH_CHECK_OPTION_VIOLATION: Final[str]
INSUFFICIENT_RESOURCES: Final[str]
DISK_FULL: Final[str]
OUT_OF_MEMORY: Final[str]
TOO_MANY_CONNECTIONS: Final[str]
CONFIGURATION_LIMIT_EXCEEDED: Final[str]
PROGRAM_LIMIT_EXCEEDED: Final[str]
STATEMENT_TOO_COMPLEX: Final[str]
TOO_MANY_COLUMNS: Final[str]
TOO_MANY_ARGUMENTS: Final[str]
OBJECT_NOT_IN_PREREQUISITE_STATE: Final[str]
OBJECT_IN_USE: Final[str]
CANT_CHANGE_RUNTIME_PARAM: Final[str]
LOCK_NOT_AVAILABLE: Final[str]
UNSAFE_NEW_ENUM_VALUE_USAGE: Final[str]
OPERATOR_INTERVENTION: Final[str]
QUERY_CANCELED: Final[str]
ADMIN_SHUTDOWN: Final[str]
CRASH_SHUTDOWN: Final[str]
CANNOT_CONNECT_NOW: Final[str]
DATABASE_DROPPED: Final[str]
SYSTEM_ERROR: Final[str]
IO_ERROR: Final[str]
UNDEFINED_FILE: Final[str]
DUPLICATE_FILE: Final[str]
FILE_NAME_TOO_LONG: Final[str]
SNAPSHOT_TOO_OLD: Final[str]
CONFIG_FILE_ERROR: Final[str]
LOCK_FILE_EXISTS: Final[str]
FDW_ERROR: Final[str]
FDW_OUT_OF_MEMORY: Final[str]
FDW_DYNAMIC_PARAMETER_VALUE_NEEDED: Final[str]
FDW_INVALID_DATA_TYPE: Final[str]
FDW_COLUMN_NAME_NOT_FOUND: Final[str]
FDW_INVALID_DATA_TYPE_DESCRIPTORS: Final[str]
FDW_INVALID_COLUMN_NAME: Final[str]
FDW_INVALID_COLUMN_NUMBER: Final[str]
FDW_INVALID_USE_OF_NULL_POINTER: Final[str]
FDW_INVALID_STRING_FORMAT: Final[str]
FDW_INVALID_HANDLE: Final[str]
FDW_INVALID_OPTION_INDEX: Final[str]
FDW_INVALID_OPTION_NAME: Final[str]
FDW_OPTION_NAME_NOT_FOUND: Final[str]
FDW_REPLY_HANDLE: Final[str]
FDW_UNABLE_TO_CREATE_EXECUTION: Final[str]
FDW_UNABLE_TO_CREATE_REPLY: Final[str]
FDW_UNABLE_TO_ESTABLISH_CONNECTION: Final[str]
FDW_NO_SCHEMAS: Final[str]
FDW_SCHEMA_NOT_FOUND: Final[str]
FDW_TABLE_NOT_FOUND: Final[str]
FDW_FUNCTION_SEQUENCE_ERROR: Final[str]
FDW_TOO_MANY_HANDLES: Final[str]
FDW_INCONSISTENT_DESCRIPTOR_INFORMATION: Final[str]
FDW_INVALID_ATTRIBUTE_VALUE: Final[str]
FDW_INVALID_STRING_LENGTH_OR_BUFFER_LENGTH: Final[str]
FDW_INVALID_DESCRIPTOR_FIELD_IDENTIFIER: Final[str]
PLPGSQL_ERROR: Final[str]
RAISE_EXCEPTION: Final[str]
NO_DATA_FOUND: Final[str]
TOO_MANY_ROWS: Final[str]
ASSERT_FAILURE: Final[str]
INTERNAL_ERROR: Final[str]
DATA_CORRUPTED: Final[str]
INDEX_CORRUPTED: Final[str]
IDLE_SESSION_TIMEOUT: Final[str]
SQL_JSON_ITEM_CANNOT_BE_CAST_TO_TARGET_TYPE: Final[str]
TRANSACTION_TIMEOUT: Final[str]



from _typeshed import Incomplete

class BaseServer:
    SIGNATURE_METHODS: Incomplete
    SUPPORTED_SIGNATURE_METHODS: Incomplete
    EXPIRY_TIME: int
    @classmethod
    def register_signature_method(cls, name, verify) -> None: ...
    def validate_timestamp_and_nonce(self, request) -> None: ...
    def validate_oauth_signature(self, request) -> None: ...
    def get_client_by_id(self, client_id) -> None: ...
    def exists_nonce(self, nonce, request) -> None: ...



from logging import Logger
from typing import Final

from aws_xray_sdk.core.models.entity import Entity

log: Logger
PROTOCOL_HEADER: Final[str]
PROTOCOL_DELIMITER: Final[str]
DEFAULT_DAEMON_ADDRESS: Final[str]

class UDPEmitter:
    def __init__(self, daemon_address: str = "127.0.0.1:2000") -> None: ...
    def send_entity(self, entity: Entity) -> None: ...
    def set_daemon_address(self, address: str | None) -> None: ...
    @property
    def ip(self) -> str: ...
    @property
    def port(self) -> int: ...



from _typeshed import GenericPath
from collections.abc import Iterable, Iterator, Sequence
from re import Pattern
from typing import Final, NoReturn

from pyflakes.reporter import Reporter

__all__ = ["check", "checkPath", "checkRecursive", "iterSourceCode", "main"]

PYTHON_SHEBANG_REGEX: Final[Pattern[bytes]]

def check(codeString: str, filename: str, reporter: Reporter | None = None) -> int: ...
def checkPath(filename: str, reporter: Reporter | None = None) -> int: ...
def isPythonFile(filename: str) -> bool: ...
def iterSourceCode(paths: Iterable[GenericPath[str]]) -> Iterator[GenericPath[str]]: ...
def checkRecursive(paths: Iterable[GenericPath[str]], reporter: Reporter) -> int: ...
def main(prog: str | None = None, args: Sequence[str] | None = None) -> NoReturn: ...



from _typeshed import Incomplete, StrOrBytesPath
from typing import Final

from reportlab.lib.rl_accel import unicode2T1 as unicode2T1

__version__: Final[str]
standardFonts: Incomplete
standardEncodings: Incomplete

class FontError(Exception): ...
class FontNotFoundError(Exception): ...

def parseAFMFile(afmFileName: StrOrBytesPath) -> tuple[dict[Incomplete, Incomplete], list[Incomplete]]: ...

class TypeFace:
    name: Incomplete
    glyphNames: Incomplete
    glyphWidths: Incomplete
    ascent: int
    descent: int
    familyName: Incomplete
    bold: int
    italic: int
    requiredEncoding: str
    builtIn: int
    def __init__(self, name) -> None: ...
    def getFontFiles(self): ...
    def findT1File(self, ext: str = ".pfb"): ...

def bruteForceSearchForFile(fn, searchPath=None): ...
def bruteForceSearchForAFM(faceName): ...

class Encoding:
    name: Incomplete
    frozen: int
    baseEncodingName: Incomplete
    vector: Incomplete
    def __init__(self, name, base=None) -> None: ...
    def __getitem__(self, index): ...
    def __setitem__(self, index, value) -> None: ...
    def freeze(self) -> None: ...
    def isEqual(self, other): ...
    def modifyRange(self, base, newNames) -> None: ...
    def getDifferences(self, otherEnc): ...
    def makePDFObject(self): ...

standardT1SubstitutionFonts: Incomplete

class Font:
    fontName: Incomplete
    encoding: Incomplete
    encName: Incomplete
    substitutionFonts: Incomplete
    shapable: bool
    def __init__(self, name, faceName, encName, substitutionFonts=None) -> None: ...
    def stringWidth(self, text: str | bytes, size: float, encoding: str = "utf8") -> float: ...
    def addObjects(self, doc) -> None: ...

PFB_MARKER: Final[str]
PFB_ASCII: Final[str]
PFB_BINARY: Final[str]
PFB_EOF: Final[str]

class EmbeddedType1Face(TypeFace):
    afmFileName: Incomplete
    pfbFileName: Incomplete
    requiredEncoding: Incomplete
    def __init__(self, afmFileName, pfbFileName) -> None: ...
    def getFontFiles(self): ...
    def addObjects(self, doc): ...

def registerTypeFace(face) -> None: ...
def registerEncoding(enc) -> None: ...
def registerFontFamily(family, normal=None, bold=None, italic=None, boldItalic=None) -> None: ...
def registerFont(font) -> None: ...
def getTypeFace(faceName): ...
def getEncoding(encName): ...
def findFontAndRegister(fontName: str) -> Font: ...
def getFont(fontName: str) -> Font: ...
def getAscentDescent(fontName: str, fontSize: float | None = None): ...
def getAscent(fontName: str, fontSize: float | None = None): ...
def getDescent(fontName: str, fontSize: float | None = None): ...
def getRegisteredFontNames() -> list[Incomplete]: ...
def stringWidth(text: str | bytes, fontName: str, fontSize: float, encoding: str = "utf8") -> float: ...
def dumpFontData() -> None: ...
def test3widths(texts) -> None: ...
def testStringWidthAlgorithms() -> None: ...
def test() -> None: ...



import logging
import re
from _typeshed import Incomplete, MaybeNone, SupportsWrite
from collections.abc import Generator, Iterator
from typing import Any, AnyStr, Final, Literal, TypeVar, overload
from typing_extensions import Self

_V = TypeVar("_V", bound=VBase)
_W = TypeVar("_W", bound=SupportsWrite[bytes])

VERSION: Final[str]

def to_unicode(value: str | bytes | bytearray) -> str: ...
def to_basestring(s: str | bytes) -> bytes: ...

logger: logging.Logger
DEBUG: bool
CR: str
LF: str
CRLF: str
SPACE: str
TAB: str
SPACEORTAB: str

class VBase:
    group: Incomplete | None
    behavior: Incomplete | None
    parentBehavior: Incomplete | None
    isNative: bool
    def __init__(self, group=None) -> None: ...
    def copy(self, copyit: VBase) -> None: ...
    def validate(self, *args, **kwds) -> bool: ...
    def getChildren(self) -> list[Incomplete]: ...
    def clearBehavior(self, cascade: bool = True) -> None: ...
    def autoBehavior(self, cascade: bool = False) -> None: ...
    def setBehavior(self, behavior, cascade: bool = True) -> None: ...
    def transformToNative(self): ...
    def transformFromNative(self): ...
    def transformChildrenToNative(self) -> None: ...
    def transformChildrenFromNative(self, clearBehavior: bool = True) -> None: ...
    # Use Any because args and kwargs are passed to the behavior object
    @overload
    def serialize(
        self, buf: None = None, lineLength: int = 75, validate: bool = True, behavior=None, *args: Any, **kwargs: Any
    ) -> str: ...
    @overload
    def serialize(self, buf: _W, lineLength: int = 75, validate: bool = True, behavior=None, *args: Any, **kwargs: Any) -> _W: ...

def toVName(name: str, stripNum: int = 0, upper: bool = False) -> str: ...

class ContentLine(VBase):
    name: str
    encoded: bool
    params: dict[Incomplete, list[Incomplete]]
    singletonparams: list[Incomplete]
    isNative: bool
    lineNumber: int | None
    value: str
    def __init__(
        self,
        name: str,
        params: dict[Incomplete, list[Incomplete]],
        value: str,
        group=None,
        encoded: bool = False,
        isNative: bool = False,
        lineNumber: int | None = None,
        *args,
        **kwds,
    ) -> None: ...
    @classmethod
    def duplicate(cls, copyit) -> Self: ...
    def copy(self, copyit) -> None: ...
    def __eq__(self, other): ...
    def __getattr__(self, name: str): ...
    def __setattr__(self, name: str, value) -> None: ...
    def __delattr__(self, name: str) -> None: ...
    def valueRepr(self) -> str: ...
    def __unicode__(self) -> str: ...
    def prettyPrint(self, level: int = 0, tabwidth: int = 3) -> None: ...

class Component(VBase):
    contents: dict[str, list[VBase]]
    name: str
    useBegin: bool
    def __init__(self, name: str | None = None, *args, **kwds) -> None: ...
    @classmethod
    def duplicate(cls, copyit) -> Self: ...
    def copy(self, copyit) -> None: ...
    def setProfile(self, name: str) -> None: ...
    def __getattr__(self, name: str): ...
    normal_attributes: list[str]
    def __setattr__(self, name: str, value) -> None: ...
    def __delattr__(self, name: str) -> None: ...
    def getChildValue(self, childName: str, default=None, childNumber: int = 0): ...
    @overload
    def add(self, objOrName: _V, group: str | None = None) -> _V: ...
    @overload
    def add(self, objOrName: Literal["vevent"], group: str | None = None) -> Component: ...
    @overload
    def add(
        self, objOrName: Literal["uid", "summary", "description", "dtstart", "dtend"], group: str | None = None
    ) -> ContentLine: ...
    @overload
    def add(self, objOrName: str, group: str | None = None) -> Any: ...  # returns VBase sub-class
    def remove(self, obj) -> None: ...
    def getChildren(self) -> list[Incomplete]: ...
    def components(self) -> Generator[Component]: ...
    def lines(self) -> Generator[ContentLine]: ...
    def sortChildKeys(self) -> list[Incomplete]: ...
    def getSortedChildren(self) -> list[Incomplete]: ...
    def setBehaviorFromVersionLine(self, versionLine) -> None: ...
    def transformChildrenToNative(self) -> None: ...
    def transformChildrenFromNative(self, clearBehavior: bool = True) -> None: ...
    def prettyPrint(self, level: int = 0, tabwidth: int = 3) -> None: ...

class VObjectError(Exception):
    msg: str
    lineNumber: int
    def __init__(self, msg: str, lineNumber: int | None = None) -> None: ...

class ParseError(VObjectError): ...
class ValidateError(VObjectError): ...
class NativeError(VObjectError): ...

patterns: dict[str, str]
param_values_re: re.Pattern[str]
params_re: re.Pattern[str]
line_re: re.Pattern[str]
begin_re: re.Pattern[str]

def parseParams(string: str) -> list[list[Any]]: ...  # Any was taken from re module stubs
def parseLine(
    line: str, lineNumber: int | None = None
) -> tuple[str, list[list[Any]], str | MaybeNone, str | MaybeNone]: ...  # Any is result of parseParams()

wrap_re: re.Pattern[str]
logical_lines_re: re.Pattern[str]
testLines: str

def getLogicalLines(fp, allowQP: bool = True) -> Generator[tuple[str, int]]: ...
def textLineToContentLine(text, n: int | None = None) -> ContentLine: ...
def dquoteEscape(param: str) -> str: ...
def foldOneLine(outbuf: SupportsWrite[AnyStr], input: AnyStr, lineLength: int = 75) -> None: ...
def defaultSerialize(obj: Component | ContentLine, buf, lineLength: int): ...

class Stack:
    stack: list[Incomplete]
    def __len__(self) -> int: ...
    def top(self): ...
    def topName(self): ...
    def modifyTop(self, item) -> None: ...
    def push(self, obj) -> None: ...
    def pop(self): ...

def readComponents(
    streamOrString, validate: bool = False, transform: bool = True, ignoreUnreadable: bool = False, allowQP: bool = False
) -> Iterator[Component]: ...
def readOne(stream, validate: bool = False, transform: bool = True, ignoreUnreadable: bool = False, allowQP: bool = False): ...
def registerBehavior(behavior, name: str | None = None, default: bool = False, id=None) -> None: ...
def getBehavior(name: str, id=None): ...
def newFromBehavior(name: str, id=None) -> Component | ContentLine: ...
def backslashEscape(s: str) -> str: ...
